%define         enable_checks            0

%define         major                    3
%define         libname                  %mklibname %{name} %{major}
%define         develname                %mklibname %{name} -d
%define         staticdevelname          %mklibname %{name} -d -s

%define         libmpiname               %mklibname %{name}mpi %{major}
%define         libompname               %mklibname %{name}omp %{major}

Summary:        Fast Fourier transform library
Name:           fftw
Version:        3.3.10
Release:        %mkrel 2
License:        GPLv2+
Group:          System/Libraries

URL:            http://www.fftw.org
Source:         ftp://ftp.fftw.org/pub/fftw/%{name}-%{version}.tar.gz
BuildRequires:  gcc-gfortran
%ifarch %ix86 x86_64
BuildRequires:  quadmath-devel
%endif
BuildRequires:  libgomp-devel
BuildRequires:  pkgconfig(ompi)
BuildRequires:  openmpi
BuildRequires:  perl

%description
FFTW is a collection of fast C routines for computing the Discrete
Fourier Transform in one or more dimensions. It includes complex,
real, and parallel transforms, can handle arbitrary array sizes
efficiently and can be called from Fortran.

%package wisdom
Summary:        FFTW-wisdom file generator
Group:          Development/Other

%description wisdom
This package contains a wisdom file generator to be used with the FFTW
Fourier transform library. These files contain saved information about how
to optimally compute transforms of various sizes.



%package -n %{libname}
Summary:        Fast Fourier transform library
Group:          System/Libraries
Provides:       %{name} = %{version}-%{release}
Obsoletes:      %{name} < 3.3

%description -n %{libname}
FFTW is a collection of fast C routines for computing the Discrete Fourier
Transform in one or more dimensions.  It includes complex, real, and
parallel transforms, and can handle arbitrary array sizes efficiently.



%package -n %{libmpiname}
Summary:        MPI-parallel fast Fourier transform library
Group:          System/Libraries
Provides:       %{name}-mpi = %{version}-%{release}

%description -n %{libmpiname}
%{summary}.



%package -n %{libompname}
Summary:        OpenMP-parallel fast Fourier transform library
Group:          System/Libraries
Provides:       %{name}-openmp = %{version}-%{release}
Provides:       %{name}-omp = %{version}-%{release}

%description -n %{libompname}
%{summary}.



%package -n %{develname}
Summary:        Headers, libraries, & docs for the FFTW fast Fourier transform library
Group:          Development/C
Requires:       pkgconfig(ompi)
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libompname} = %{version}-%{release}
Requires:       %{libmpiname} = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}
Provides:       %{name}%{major}-devel = %{version}-%{release}
Obsoletes:      %{libname}-devel < 3.3
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the additional header files, documentation, and
libraries you need to develop programs using the FFTW fast Fourier
transform library.



%package -n %{staticdevelname}
Summary:        Static development files for the FFTW fast Fourier transform library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       lib%{name}-devel = %{version}-%{release}
Provides:       lib%{name}-static-devel = %{version}-%{release}
Obsoletes:      %{libname}-static-devel < 3.3

%description -n %{staticdevelname}
%{summary}.


%prep
%setup -q

%build
export F77="gfortran"
export MPILIBS="-lmpi"
if [ ! -d build-std ]; then
        mkdir build-std
fi
pushd build-std
CONFIGURE_TOP=.. %configure \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-mpi \
                    --enable-fortran \
                    %ifarch x86_64
                    --enable-sse2 \
                    --enable-avx \
                    %endif
                    --infodir=%{_infodir}

%make_build
popd

if [ ! -d build-float ]; then
        mkdir build-float
fi
pushd build-float
CONFIGURE_TOP=.. %configure \
                    --enable-float \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-mpi \
                    --enable-fortran \
                    %ifarch x86_64
                    --enable-sse2 \
                    --enable-avx \
                    %endif
                    --infodir=%{_infodir}
%make_build
popd

#SSE2 and AVX do not work with long-double
if [ ! -d build-long-double ]; then
        mkdir build-long-double
fi
pushd build-long-double
CONFIGURE_TOP=.. %configure \
                    --enable-long-double \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-mpi \
                    --enable-fortran \
                    --infodir=%{_infodir}
%make_build
popd

%ifarch %{ix86} x86_64
#SSE2,AVX, and MPI do not work with quad-precision
mkdir build-quad-precision
pushd build-quad-precision
CONFIGURE_TOP=.. %configure \
                    --enable-quad-precision \
                    --enable-shared \
                    --enable-threads \
                    --enable-openmp \
                    --enable-fortran \
                    --infodir=%{_infodir}
%make_build
%endif


%check
%if %enable_checks
make check -C build-std
make check -C build-float
make check -C build-long-double
make check -C build-quad-precision
%endif

%install
pushd build-std
%make_install
popd
pushd build-float
%make_install
popd
pushd build-long-double
%make_install
popd
%ifarch %{ix86} x86_64
pushd build-quad-precision
%make_install
popd
%endif

rm -fr %{buildroot}/%{_docdir}/Make*
find %{buildroot}%{_libdir} -name *.la -delete

%files -n %{name}-wisdom
%{_bindir}/fftw*-wisdom
%{_bindir}/fftw-wisdom-to-conf
%{_mandir}/man1/fftw-wisdom-to-conf.*
%{_mandir}/man1/fftw*-wisdom.*


%files -n %{libname}
%doc AUTHORS CO* NEWS README TODO 
%{_libdir}/libfftw3.so.%{major}{,.*}
%{_libdir}/libfftw3f.so.%{major}{,.*}
%{_libdir}/libfftw3l.so.%{major}{,.*}
%ifarch %{ix86} x86_64
%{_libdir}/libfftw3q.so.%{major}{,.*}
%endif
%{_libdir}/libfftw3*_threads.so.%{major}{,.*}


%files -n %{libmpiname}
%{_libdir}/libfftw3*_mpi.so.%{major}{,.*}


%files -n %{libompname}
%{_libdir}/libfftw3*_omp.so.%{major}{,.*}


%files -n %{develname}
%doc ChangeLog doc/*
%{_includedir}/*fftw*.h
%{_includedir}/fftw3*.f*
%{_infodir}/fftw%{major}.info*
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libfftw*.so
%{_libdir}/cmake/fftw3


%files -n %{staticdevelname}
%{_libdir}/libfftw*.a


%changelog
* Thu Mar 31 2022 umeabot <umeabot> 3.3.10-2.mga9
+ Revision: 1837249
- Mageia 9 Mass Rebuild

* Mon Feb 21 2022 eatdirt <eatdirt> 3.3.10-1.mga9
+ Revision: 1782330
- Upgrade to bug fix release 3.3.10

* Wed Dec 30 2020 luigiwalser <luigiwalser> 3.3.9-1.mga8
+ Revision: 1665861
- 3.3.9

* Sat Aug 01 2020 joequant <joequant> 3.3.8-5.mga8
+ Revision: 1610057
- remove install-info script since info may not be installed

* Fri Feb 14 2020 umeabot <umeabot> 3.3.8-4.mga8
+ Revision: 1523079
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Feb 17 2019 wally <wally> 3.3.8-3.mga7
+ Revision: 1367940
- require openmpi-devel with devel pkg

* Sun Sep 23 2018 umeabot <umeabot> 3.3.8-2.mga7
+ Revision: 1297691
- Mageia 7 Mass Rebuild

* Mon Jul 30 2018 daviddavid <daviddavid> 3.3.8-1.mga7
+ Revision: 1245963
- new version: 3.3.8 (Fixed AVX, AVX2 for gcc-8)

* Fri May 18 2018 eatdirt <eatdirt> 3.3.7-2.mga7
+ Revision: 1230325
- Rebuild for new openmpi

* Sun May 13 2018 eatdirt <eatdirt> 3.3.7-1.mga7
+ Revision: 1229028
- Upgrade to version 3.3.7

* Sun Oct 08 2017 eatdirt <eatdirt> 3.3.6-3.mga7
+ Revision: 1170155
- Rebuild for new openmpi

* Wed Jul 26 2017 wally <wally> 3.3.6-2.mga7
+ Revision: 1131118
- rebuild for new openmpi (to sync armv5tl)

* Mon Apr 03 2017 eatdirt <eatdirt> 3.3.6-1.mga6
+ Revision: 1095791
- Upgrade to bug fix release 3.3.6-pl2

* Fri Dec 02 2016 tmb <tmb> 3.3.5-2.mga6
+ Revision: 1071627
- rebuild for new openmpi

* Fri Sep 09 2016 luigiwalser <luigiwalser> 3.3.5-1.mga6
+ Revision: 1051181
- 3.3.5

* Tue Mar 29 2016 eatdirt <eatdirt> 3.3.4-6.mga6
+ Revision: 996083
- Add missing requires (#18085)

* Sun Feb 14 2016 umeabot <umeabot> 3.3.4-5.mga6
+ Revision: 960079
- Mageia 6 Mass Rebuild

* Wed Sep 30 2015 daviddavid <daviddavid> 3.3.4-4.mga6
+ Revision: 885292
- rebuild for new openmpi 1.10.0

* Wed Oct 15 2014 umeabot <umeabot> 3.3.4-3.mga5
+ Revision: 742895
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.3.4-2.mga5
+ Revision: 679175
- Mageia 5 Mass Rebuild

* Thu Mar 20 2014 eatdirt <eatdirt> 3.3.4-1.mga5
+ Revision: 605974
- Upgrade to version 3.3.4

* Fri Oct 18 2013 umeabot <umeabot> 3.3.3-4.mga4
+ Revision: 522408
- Mageia 4 Mass Rebuild

* Fri Mar 01 2013 rtp <rtp> 3.3.3-3.mga3
+ Revision: 400750
- try to make the build short-circuit compliant
- build quadmath fftw library only on intel platforms

* Fri Jan 11 2013 umeabot <umeabot> 3.3.3-2.mga3
+ Revision: 350271
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Nov 27 2012 fwang <fwang> 3.3.3-1.mga3
+ Revision: 322230
- link with mpi
- new version 3.3.3

* Sun Sep 02 2012 eatdirt <eatdirt> 3.3.2-2.mga3
+ Revision: 287338
- Split parallel libraries into sub-packages (ease deps)

* Sun Jun 17 2012 eatdirt <eatdirt> 3.3.2-1.mga3
+ Revision: 261195
- Upgrade to version 3.3.2
  enable AVX instructions, enable MPI support
  add static-devel subpackage

* Fri Dec 09 2011 eatdirt <eatdirt> 3.3-1.mga2
+ Revision: 179767
- Upgrade to 3.3
- delete .la files
- added enable SSE2, openmp and quadruple precision

* Thu Jan 13 2011 ahmad <ahmad> 3.2.2-4.mga1
+ Revision: 8894
- drop old/unneeded scriptlets
- imported package fftw


* Thu Dec 02 2010 Oden Eriksson <oeriksson@mandriva.com> 3.2.2-3mdv2011.0
+ Revision: 605126
- rebuild

* Tue Mar 16 2010 Oden Eriksson <oeriksson@mandriva.com> 3.2.2-2mdv2010.1
+ Revision: 521125
- rebuilt for 2010.1

* Mon Jul 27 2009 Emmanuel Andry <eandry@mandriva.org> 3.2.2-1mdv2010.0
+ Revision: 400912
- New version 3.2.2
- reenable ld_no_undefined

* Fri Feb 20 2009 Lev Givon <lev@mandriva.org> 3.2.1-2mdv2009.1
+ Revision: 343394
- Build long-double libs in addition to the
  short and double libs.

* Sun Feb 15 2009 Frederik Himpe <fhimpe@mandriva.org> 3.2.1-1mdv2009.1
+ Revision: 340476
- update to new version 3.2.1

* Sun Nov 16 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 3.2-1mdv2009.1
+ Revision: 303724
- update to new version 3.2

* Mon Oct 20 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 3.1.3-1mdv2009.1
+ Revision: 295786
- update to new version 3.1.3
- enable SSE eptimizations for x86_64

* Sat Jul 12 2008 Oden Eriksson <oeriksson@mandriva.com> 3.1.2-11mdv2009.0
+ Revision: 234200
- rebuild

* Sun Jul 06 2008 Oden Eriksson <oeriksson@mandriva.com> 3.1.2-10mdv2009.0
+ Revision: 232154
- use _disable_ld_no_undefined due to build problems
- rebuild

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Oct 15 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.1.2-8mdv2008.1
+ Revision: 98557
- Use _extension macro instead off hardcoded extension of info files (as
  suggested by Adam Willianson on cooker ML sometime ago).

* Sun Sep 30 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.1.2-7mdv2008.0
+ Revision: 94076
- Reference the right fftw3.info file in /usr/share/info/dir.
- Don't ship duplicated fftw3.info in docdir.

* Sun Sep 30 2007 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.1.2-6mdv2008.0
+ Revision: 93938
- Fixed install_info in libfftw-devel scriptlets (*.info.bz2 ->
  *.info.lzma).

* Sun Sep 23 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 3.1.2-5mdv2008.0
+ Revision: 92420
- fix bug #33857
- make use of %%{major}

  + Thierry Vignaud <tv@mandriva.org>
    - fix man pages

* Sat Jun 23 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 3.1.2-4mdv2008.0
+ Revision: 43506
- add missing provides

* Sat Jun 23 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 3.1.2-3mdv2008.0
+ Revision: 43466
- new devel library policy
- add check section
- remove dead entries
- no need to hardcode gcc-gfortran
- spec file clean


* Thu Mar 01 2007 Thierry Vignaud <tvignaud@mandriva.com> 3.1.2-2mdv2007.0
+ Revision: 130762
- Import fftw

* Thu Mar 01 2007 Thierry Vignaud <tvignaud@mandrakesoft.com> 3.1.2-2mdv2007.1
- do not package big ChangeLog

* Fri Jul 07 2006 Austin Acton <austin@mandriva.org> 3.1.2-1mdk
- New release 3.1.2

* Mon May 15 2006 Stefan van der Eijk <stefan@eijk.nu> 3.1.1-2mdk
- rebuild for sparc

* Mon Mar 20 2006 Austin Acton <austin@mandriva.org> 3.1.1-1mdk
- New release 3.1.1

* Mon Jan 30 2006 Austin Acton <austin@mandriva.org> 3.1-1mdk
- 3.1
- mkrel

* Thu Aug 18 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.0.1-6mdk
- libtool fixes
- use gfortran in 2006
- make check by default

* Mon Aug 09 2004 Austin Acton <austin@mandrake.org> 3.0.1-5mdk
- rebuild

* Wed Aug 04 2004 Götz Waschk <waschk@linux-mandrake.com> 3.0.1-4mdk
- add fftw3-devel provides (helps with slbd)
- fix rpm groups

